==> opentelemetry-exporter-gcp-trace-1.0.0rc0.tar.gz: opentelemetry-exporter-gcp-trace-1.0.0rc0/CHANGELOG.md <==
# Changelog

## Unreleased

## Version 1.0.0rc0

Released 2021-04-22

- Drop support for Python 3.5
  ([#123](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/123))
- Split cloud trace and cloud monitoring exporters into separate packages
  ([#107](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/107))
  ([#122](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/122))

## Version 0.18b0

Released 2021-03-31

## Version 0.17b0

Released 2021-02-04

## Version 0.16b1

Released 2021-01-14

- Add mapping between opentelemetry and google traces attributes
  ([#90](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/90))

## Version 0.15b0

Released 2020-11-04

## Version 0.14b0

Released 2020-10-27

- Fix breakages for opentelemetry-python v0.14b0
  ([#79](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/79),
  [#83](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/83))

## Version 0.13b0

Released 2020-09-17

## Version 0.12b0

Released 2020-08-17

- Add spankind support for trace exporter
  ([#58](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/58))

## Version 0.11b0

Released 2020-08-05

- Add support for resources
  ([#853](https://github.com/open-telemetry/opentelemetry-python/pull/853))

## Version 0.10b0

Released 2020-06-23

- Add g.co/agent label for Google internal metrics tracking
  ([#833](https://github.com/open-telemetry/opentelemetry-python/pull/833))
- Adding trouble-shooting tips
  ([#827](https://github.com/open-telemetry/opentelemetry-python/pull/827))
- Added Cloud Trace context propagation
  ([#819](https://github.com/open-telemetry/opentelemetry-python/pull/819))
- Added tests to tox coverage files
  ([#804](https://github.com/open-telemetry/opentelemetry-python/pull/804))
- Add ability for exporter to add unique identifier
  ([#841](https://github.com/open-telemetry/opentelemetry-python/pull/841))
- Added tests to tox coverage files
  ([#804](https://github.com/open-telemetry/opentelemetry-python/pull/804))

## 0.9b0

Released 2020-06-10

- Initial release

==> opentelemetry-exporter-gcp-trace-1.2.0.tar.gz: opentelemetry-exporter-gcp-trace-1.2.0/CHANGELOG.md <==
# Changelog

## Unreleased

## Version 1.2.0

Released 2022-04-05

- Add entry point for Cloud Trace exporter to work with auto instrumentation
  ([#179](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/179))

## Version 1.1.0

Released 2022-01-13

- Add optional resource attributes to trace spans with regex
  ([#145](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/145))
- Upgrade `google-cloud-trace` dependency to version 1.1 or newer.
  ([#170](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/170))
- Fix span attribute value truncation
  ([#173](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/173))

## Version 1.0.0

Released 2021-05-13

## Version 1.0.0rc0

Released 2021-04-22

- Drop support for Python 3.5
  ([#123](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/123))
- Split cloud trace and cloud monitoring exporters into separate packages
  ([#107](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/107))
  ([#122](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/122))

## Version 0.18b0

Released 2021-03-31

## Version 0.17b0

Released 2021-02-04

## Version 0.16b1

Released 2021-01-14

- Add mapping between opentelemetry and google traces attributes
  ([#90](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/90))

## Version 0.15b0

Released 2020-11-04

## Version 0.14b0

Released 2020-10-27

- Fix breakages for opentelemetry-python v0.14b0
  ([#79](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/79),
  [#83](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/83))

## Version 0.13b0

Released 2020-09-17

## Version 0.12b0

Released 2020-08-17

- Add spankind support for trace exporter
  ([#58](https://github.com/GoogleCloudPlatform/opentelemetry-operations-python/pull/58))

## Version 0.11b0

Released 2020-08-05

- Add support for resources
  ([#853](https://github.com/open-telemetry/opentelemetry-python/pull/853))

## Version 0.10b0

Released 2020-06-23

- Add g.co/agent label for Google internal metrics tracking
  ([#833](https://github.com/open-telemetry/opentelemetry-python/pull/833))
- Adding trouble-shooting tips
  ([#827](https://github.com/open-telemetry/opentelemetry-python/pull/827))
- Added Cloud Trace context propagation
  ([#819](https://github.com/open-telemetry/opentelemetry-python/pull/819))
- Added tests to tox coverage files
  ([#804](https://github.com/open-telemetry/opentelemetry-python/pull/804))
- Add ability for exporter to add unique identifier
  ([#841](https://github.com/open-telemetry/opentelemetry-python/pull/841))
- Added tests to tox coverage files
  ([#804](https://github.com/open-telemetry/opentelemetry-python/pull/804))

## 0.9b0

Released 2020-06-10

- Initial release
